#
# spec file for package python-opentelemetry-semantic-conventions
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-semantic-conventions
Version:        0.50b0
Release:        1.1
Summary:        OpenTelemetry Semantic Conventions
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-semantic-conventions
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-semantic-conventions/opentelemetry_semantic_conventions-%{version}.tar.gz
BuildRequires:  %{python_module hatch-vcs}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Deprecated >= 1.2.6
Requires:       python-opentelemetry-api >= 1.29.0
BuildArch:      noarch
%python_subpackages

%description
This library contains generated code for the semantic conventions
defined by the OpenTelemetry specification.

%prep
%setup -q -n opentelemetry_semantic_conventions-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%dir %{python_sitelib}/opentelemetry
%{python_sitelib}/opentelemetry/semconv
%{python_sitelib}/opentelemetry_semantic_conventions-%{version}.dist-info

%changelog
* Wed Jan  8 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.50b0
  * Fix crash exporting a log record with None body
  * Fix metrics export with exemplar and no context and filtering observable instruments
  * Fix recursion error with sdk disabled and handler added to root logger
  * sdk: setup EventLogger when OTEL_PYTHON_LOGGING_AUTO_INSTRUMENTATION_ENABLED is set
  * api: fix logging of duplicate EventLogger setup warning
  * sdk: fix setting of process owner in ProcessResourceDetector
  * sdk: fix serialization of logs severity_number field to int
  * Remove `TestBase.assertEqualSpanInstrumentationInfo` method,
    use `assertEqualSpanInstrumentationScope` instead
  * sdk: instantiate lazily `ExemplarBucket`s in `ExemplarReservoir`s
  * semantic-conventions: Bump to 1.29.0
- from version 0.49b0
  * Removed superfluous py.typed markers and added them where they were missing
  * Include metric info in encoding exceptions
  * sdk: Add support for log formatting
  * sdk: Add Host resource detector
  * sdk: Implementation of exemplars
  * Implement events sdk
  * Update semantic conventions to version 1.28.0
  * Add support to protobuf 5+ and drop support to protobuf 3 and 4
  * Update environment variable descriptions to match signal
  * Record logger name as the instrumentation scope name
  * Fix memory leak in exporter and reader
  * Drop `OTEL_PYTHON_EXPERIMENTAL_DISABLE_PROMETHEUS_UNIT_NORMALIZATION` environment variable
  * Improve compatibility with other logging libraries that override
    `LogRecord.getMessage()` in order to customize message formatting
- Update Requires from pyproject.toml
- Use %%{version} in BuildRequires for dependencies
* Fri Aug 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.48b0
  * Implementation of Events API (#4054)
  * Make log sdk add `exception.message` to logRecord for exceptions
    whose argument is an exception not a string message (#4122)
  * Fix use of `link.attributes.dropped`, which may not exist (#4119)
  * Running mypy on SDK resources (#4053)
  * Added py.typed file to top-level module (#4084)
  * Drop Final annotation from Enum in semantic conventions (#4085)
  * Update log export example to not use root logger (#4090)
  * sdk: Add OS resource detector (#3992)
  * sdk: Accept non URL-encoded headers in `OTEL_EXPORTER_OTLP_*HEADERS`
    to match other languages SDKs (#4103)
  * Update semantic conventions to version 1.27.0 (#4104)
  * Add support to type bytes for OTLP AnyValue (#4128)
  * Export ExponentialHistogram and ExponentialHistogramDataPoint (#4134)
  * Implement Client Key and Certificate File Support for All OTLP Exporters (#4116)
  * Remove `_start_time_unix_nano` attribute from `_ViewInstrumentMatch` in favor
    of using `time_ns()` at the moment when the aggregation object is created (#4137)
- for changes between 0.44b0 and 0.48b0 see upstream CHANGELOG.md
* Sat Mar 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- update to 0.44b0:
  * Use Attribute rather than boundattribute in logrecord (#3567)
  * Fix flush error when no LoggerProvider configured for LoggingHandler (#3608)
  * Fix OTLPMetricExporter ignores preferred_aggregation property (#3603)
  * Logs: set observed_timestamp field (#3565)
  * Add missing Resource SchemaURL in OTLP exporters (#3652)
  * Fix loglevel warning text (#3566)
  * Prometheus Exporter string representation for target_info labels (#3659)
  * Logs: ObservedTimestamp field is missing in console exporter output (#3564)
  * Fix explicit bucket histogram aggregation (#3429)
  * Add code.lineno, code.function and code.filepath to all logs (#3645)
  * Add Synchronous Gauge instrument (#3462)
  * Drop support for 3.7 (#3668)
  * Include key in attribute sequence warning (#3639)
  * Upgrade markupsafe, Flask and related dependencies to dev and test
    environments (#3609)
  * Handle HTTP 2XX responses as successful in OTLP exporters (#3623)
  * Improve Resource Detector timeout messaging (#3645)
  * Add Proxy classes for logging (#3575)
  * Remove dependency on 'backoff' library (#3679)
* Thu Jan  4 2024 Dirk Müller <dmueller@suse.com>
- update to 0.43b0:
  * Prometheus exporter sanitize info metric
  * Remove Jaeger exporters
  * Log stacktrace on `UNKNOWN` status OTLP export error
  * Fix OTLPExporterMixin shutdown timeout period
  * Handle `taskName` `logrecord` attribute
  * Fix `SumAggregation` ￼
  * Fix handling of empty metric collection cycles
  * Fix error when no LoggerProvider configured for
    LoggingHandler
  * Make `opentelemetry_metrics_exporter` entrypoint support pull
    exporters
  * Allow instrument names to have '/' and up to 255 characters
  * Do not load Resource on sdk import
  * Update semantic conventions to version 1.21.0
  * Add missing schema_url in global api for logging and metrics
  * Prometheus exporter support for auto instrumentation
  * Drop `setuptools` runtime requirement.
  * Update the body type in the log ($3343)
  * Add max_scale option to Exponential Bucket Histogram
    Aggregation
  * Use BoundedAttributes instead of raw dict to extract
    attributes from LogRecord
  * Support dropped_attributes_count in LogRecord and exporters
  * Add unit to view instrument selection criteria
  * Upgrade opentelemetry-proto to 0.20 and regen #3355)
  * Include endpoint in Grpc transient error warning #3362)
  * Fixed bug where logging export is tracked as trace #3375)
  * Select histogram aggregation with an environment variable
  * Move Protobuf encoding to its own package
  * Add experimental feature to detect resource detectors in auto
    instrumentation
  * Fix exporting of ExponentialBucketHistogramAggregation from
    opentelemetry.sdk.metrics.view
  * Fix headers types mismatch for OTLP Exporters
  * Fix suppress instrumentation for log batch processor
  * Add speced out environment variables and arguments for
    BatchLogRecordProcessor
* Thu Nov  4 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.25b2
